@@ -26,25 +26,32 @@
 
 #----------------------------------------------------------------------------
 from Foam import FOAM_VERSION
-if FOAM_VERSION( ">=", "010701" ):
+if FOAM_VERSION( "==", "010701" ):
     from interDyMFlux.r1_7_1 import *
     pass
 
 
 #--------------------------------------------------------------------------------------
 from Foam import FOAM_VERSION
-if FOAM_VERSION( ">=", "020000" ):
+if FOAM_VERSION( "==", "020000" ) or FOAM_VERSION( "==", "020001" ):
     from interDyMFlux.r2_0_0 import *
     pass
 
 
 #--------------------------------------------------------------------------------------
 from Foam import FOAM_VERSION
-if FOAM_VERSION( ">=", "020100" ):
+if FOAM_VERSION( "==", "020100" ):
     from interDyMFlux.r2_1_0 import *
     pass
 
 
+#--------------------------------------------------------------------------------------
+from Foam import FOAM_VERSION
+if FOAM_VERSION( ">=", "020101" ):
+    from interDyMFlux.r2_1_1 import *
+    pass
+
+
 #--------------------------------------------------------------------------------------
 def entry_point():
     try:
