@@ -168,19 +168,7 @@ def alphaCourantNo( runTime, mesh, alpha1, phi ):
 
 
 #----------------------------------------------------------------------------------------
-def fun_Urel( mesh, U ):
-# Calculate the relative velocity used to map the relative flux phi
-     Urel = ref.volVectorField( ref.word( "Urel" ), U )
-     if mesh.moving():
-         Urel -= ref.fvc.reconstruct( ref.fvc.meshPhi( U ) )
-         pass
-     # Do any mesh changes
-     mesh.update()
-     pass
-
-
-#----------------------------------------------------------------------------------------
-def fun_correctPhi( runTime, mesh, phi, phiAbs, p, p_rgh, rho, U, cumulativeContErr, pimple, pRefCell, pRefValue ):
+def fun_correctPhi( runTime, mesh, phi, p, p_rgh, rho, U, cumulativeContErr, pimple, pRefCell, pRefValue ):
     
     cumulativeContErr = ref.ContinuityErrs( phi, runTime, mesh, cumulativeContErr )
     pcorrTypes = ref.wordList( p_rgh.ext_boundaryField().size(), ref.zeroGradientFvPatchScalarField.typeName )
@@ -204,18 +192,14 @@ def fun_correctPhi( runTime, mesh, phi, phiAbs, p, p_rgh, rho, U, cumulativeCont
     
     ref.adjustPhi(phi, U, pcorr)
     
-    ref.fvc.makeAbsolute( phi, U )
-    
-    while pimple.correctNonOrthogonal():
+    for nonOrth in range( pimple.nNonOrthCorr() + 1 ):
         pcorrEqn = ref.fvm.laplacian( rAUf, pcorr ) == ref.fvc.div( phi )
 
         pcorrEqn.setReference(pRefCell, pRefValue)
         pcorrEqn.solve()
 
-        if pimple.finalNonOrthogonalIter():
+        if nonOrth == pimple.nNonOrthCorr():
            phi-= pcorrEqn.flux()
-           phiAbs << phi
-           ref.fvc.makeRelative( phi, U )
            pass
     
     cumulativeContErr = ref.ContinuityErrs( phi, runTime, mesh, cumulativeContErr )
@@ -297,38 +281,37 @@ def _UEqn( mesh, alpha1, U, p, p_rgh, ghf, rho, rhoPhi, turbulence, g, twoPhaseP
 
 
 #--------------------------------------------------------------------------------------
-def _pEqn( runTime, mesh, UEqn, U, p, p_rgh, gh, ghf, phi, phiAbs, alpha1, rho, g, interface, pimple, pRefCell, pRefValue, cumulativeContErr ):
+def _pEqn( runTime, mesh, UEqn, U, p, p_rgh, gh, ghf, phi, alpha1, rho, g, interface, corr, pimple, pRefCell, pRefValue, cumulativeContErr ):
     rAU = 1.0 / UEqn.A()
     rAUf = ref.fvc.interpolate( rAU )
 
     U << rAU * UEqn.H()
-    phiAbs << ( ref.fvc.interpolate( U ) & mesh.Sf() ) + ref.fvc.ddtPhiCorr( rAU, rho, U, phiAbs )
+    phiU = ref.surfaceScalarField( ref.word( "phiU" ), ( ref.fvc.interpolate( U ) & mesh.Sf() ) );
 
     if p_rgh.needReference():
-        ref.fvc.makeRelative( phiAbs, U )
-        ref.adjustPhi( phiAbs, U, p_rgh )
-        ref.fvc.makeAbsolute( phiAbs, U )
+        ref.fvc.makeRelative( phiU, U )
+        ref.adjustPhi( phiU, U, p_rgh )
+        ref.fvc.makeAbsolute( phiU, U )
         pass
-    phi << phiAbs + ( ref.fvc.interpolate( interface.sigmaK() ) * ref.fvc.snGrad( alpha1 ) - ghf * ref.fvc.snGrad( rho ) ) * rAUf * mesh.magSf()
+    phi << phiU + ( ref.fvc.interpolate( interface.sigmaK() ) * ref.fvc.snGrad( alpha1 ) - ghf * ref.fvc.snGrad( rho ) ) * rAUf * mesh.magSf()
 
-    while pimple.correctNonOrthogonal():
+    for nonOrth in range( pimple.nNonOrthCorr() + 1 ):
         p_rghEqn = ( ref.fvm.laplacian( rAUf, p_rgh ) == ref.fvc.div( phi ) )
 
         p_rghEqn.setReference( pRefCell, ref.getRefCellValue( p_rgh, pRefCell ) )
 
-        p_rghEqn.solve( mesh.solver( p_rgh.select( pimple.finalInnerIter() ) ) )
+        p_rghEqn.solve( mesh.solver( p_rgh.select( pimple.finalInnerIter( corr, nonOrth ) ) ) )
         
-        if pimple.finalNonOrthogonalIter():
+        if nonOrth == pimple.nNonOrthCorr():
             phi -= p_rghEqn.flux()
             pass
         pass
 
-    U += rAU * ref.fvc.reconstruct( ( phi() - phiAbs ) / rAUf ) # mixed calculations
+    U += rAU * ref.fvc.reconstruct( ( phi() - phiU ) / rAUf ) # mixed calculations
     U.correctBoundaryConditions()
 
     cumulativeContErr = ref.ContinuityErrs( phi, runTime, mesh, cumulativeContErr )
 
-    phiAbs << phi
     # Make the fluxes relative to the mesh motion
     ref.fvc.makeRelative( phi, U )
 
@@ -362,10 +345,7 @@ def main_standalone( argc, argv ):
     
     pimple = man.pimpleControl( mesh )
     
-    phiAbs = ref.surfaceScalarField( ref.word( "phiAbs" ), phi )
-    ref.fvc.makeAbsolute( phiAbs, U )
-    
-    cumulativeContErr = fun_correctPhi( runTime, mesh, phi, phiAbs, p, p_rgh, rho, U, cumulativeContErr, pimple, pRefCell, pRefValue)
+    cumulativeContErr = fun_correctPhi( runTime, mesh, phi, p, p_rgh, rho, U, cumulativeContErr, pimple, pRefCell, pRefValue)
     
     CoNum, meanCoNum = ref.CourantNo( mesh, phi, runTime )
     
@@ -381,6 +361,9 @@ def main_standalone( argc, argv ):
         
         CoNum, meanCoNum = ref.CourantNo( mesh, phi, runTime )
         
+        # Make the fluxes absolute
+        ref.fvc.makeAbsolute( phi, U )
+        
         runTime = setDeltaT(  runTime, adjustTimeStep, maxCo, CoNum, maxAlphaCo, alphaCoNum, maxDeltaT )
         
         runTime.increment()
@@ -388,7 +371,8 @@ def main_standalone( argc, argv ):
         
         timeBeforeMeshUpdate = runTime.elapsedCpuTime()
 
-        fun_Urel( mesh, U )
+        # Do any mesh changes
+        mesh.update()
         
         if mesh.changing():
             ref.ext_Info() << "Execution time for mesh.update() = " << runTime.elapsedCpuTime() - timeBeforeMeshUpdate << " s" << ref.nl
@@ -397,9 +381,12 @@ def main_standalone( argc, argv ):
             pass
         
         if mesh.changing() and correctPhi:
-            cumulativeContErr = fun_correctPhi( runTime, mesh(), phi, phiAbs, p, p_rgh, rho, U, cumulativeContErr, pimple, pRefCell, pRefValue)
+            cumulativeContErr = fun_correctPhi( runTime, mesh(), phi, p, p_rgh, rho, U, cumulativeContErr, pimple, pRefCell, pRefValue)
             pass
 
+        # Make the fluxes relative to the mesh motion
+        ref.fvc.makeRelative( phi, U )
+
         if mesh.changing() and checkMeshCourantNo:
            meshCoNum, meanMeshCoNum = ref.meshCourantNo( runTime, mesh(), phi )
            pass
@@ -409,17 +396,19 @@ def main_standalone( argc, argv ):
         alphaEqnSubCycle( runTime, pimple, mesh, phi, alpha1, rho, rhoPhi, rho1, rho2, interface )
         
         # --- Pressure-velocity PIMPLE corrector loop
+        pimple.start()
         while pimple.loop():
             UEqn = _UEqn( mesh(), alpha1, U, p, p_rgh, ghf, rho, rhoPhi, turbulence, g, twoPhaseProperties, interface, pimple )
 
             # --- PISO loop
-            while pimple.correct():
-                cumulativeContErr = _pEqn( runTime, mesh, UEqn, U, p, p_rgh, gh, ghf, phi, phiAbs, alpha1, rho, g, \
-                                          interface, pimple, pRefCell, pRefValue, cumulativeContErr )
+            for corr in range( pimple.nCorr() ):
+                cumulativeContErr = _pEqn( runTime, mesh, UEqn, U, p, p_rgh, gh, ghf, phi, alpha1, rho, g, \
+                                          interface, corr, pimple, pRefCell, pRefValue, cumulativeContErr )
                 pass
             if pimple.turbCorr():
                 turbulence.correct()
                 pass
+            pimple.increment()
             pass
 
         runTime.write()
@@ -437,7 +426,7 @@ def main_standalone( argc, argv ):
 
 #--------------------------------------------------------------------------------------
 from Foam import FOAM_VERSION
-if FOAM_VERSION( ">=", "020100" ):
+if FOAM_VERSION( ">=", "020000" ):
    if __name__ == "__main__" :
       import sys, os
       argv = sys.argv
@@ -445,7 +434,7 @@ if FOAM_VERSION( ">=", "020100" ):
       pass
    pass
 else:
-   ref.ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam2.1.0 or higher \n "     
+   ref.ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam2.0.0 or higher \n "     
    pass
 
 
